#!/bin/bash
# IBM_PROLOG_BEGIN_TAG 
# This is an automatically generated prolog. 
#  
#  
#  
# Licensed Materials - Property of IBM 
#  
# Restricted Materials of IBM 
#  
# (C) COPYRIGHT International Business Machines Corp. 2002,2006 
# All Rights Reserved 
#  
# US Government Users Restricted Rights - Use, duplication or 
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp. 
#  
# IBM_PROLOG_END_TAG 
####################################################################
#
#   chswibnm command
#
#   Syntax:  chswibnm [ -a | -c | -d | -q | -r | -v
#                             | --help ] 
#
#            --help   - Prints this message
#            -a       - Used to activate the IBNM software by uncommenting the
#                          /etc/inittab entry for startIBNM
#            -d       - Used to deactivate the IBNM software by commenting out 
#                          the /etc/inittab entry for startIBNM
#            -q       - Used to query the activation status of the IBNM software
#                          by examining the /etc/inittab entry for startIBNM
#
####################################################################
#
#   Initial version - 02/26/03
#   Change history
#   9/26/05 - added new options and deregister ability WJ
#   3/28/06 - extra insurance that TopoDB and NmTrace files not writable by world
#   4/3/06 - take out extra insurance due to TopoDB possibly not ready yet
#   4/13/06 - fix HMC GA8 pThread library change
#   4/13/06 - fix for manual add of snmp trap ports
#   4/14/06 - add udp ports for snmp traps
#   5/08/06 - fix the way we handle setting up and bringing down snmp trap ports
#
####################################################################
#"@(#)35   1.11   src/hmcpok/commands/chswnm.bash, fnm.websm, hmcpok_rel3, rel30436a 8/23/04 11:10:47"

PRGRM="chswibnm"
AFLAG=0
CFLAG=0
DFLAG=0
QFLAG=0
HFLAG=0
OFLAG=0

USAGE="\nSyntax:  chswibnm [ -a | -c | -d | -o | -q | -h | --help ] \n
            -h | --help   - Prints this message \n
            -a       - Used to activate the IBNM software by uncommenting the \n\t
                          /etc/inittab entry for startIBNM.  Change isSP to isCecBpcIb. \n
            -d       - Used to deactivate the IBNM software by commenting out \n\t
                          the /etc/inittab entry for startIBNM.  Change isSP to isCecBpc.  Degregister HWS.\n 
            -q       - Used to query the activation status of the IBNM software \n\t
                          by examining the /etc/inittab entry for startIBNM.\n
            -o       - Used to activate the activation status of the IBNM software \n\t
                          by examining the /etc/inittab entry for startIBNM. \n
            -c       - Used to deactivate the activation status of the IBNM software \n\t
                          by examining the /etc/inittab entry for startIBNM \n"

# First check for existence of parameters, then check validity
if (( $# != 1 ))
then
	echo -e $USAGE 
	exit 2
else
    while test -n "$1"
        do
            case $1 in
                -a) AFLAG=1; break;;
                -d) DFLAG=1; break;;
                -q) QFLAG=1; break;;
		-h) HFLAG=1; break;;
		-c) CFLAG=1; break;;
		-o) OFLAG=1; break;;
		--help) HFLAG-1; break;;
                 *) echo -e $USAGE; exit 2;;
            esac
        done
fi

# Now make sure we are executing cut from the right path.  IN RedHat, it is
#   in /bin.  In MCP, it is in /usr/bin
if [[ -a /bin/cut ]]
then
	CUT=/bin/cut
else
	CUT=/usr/bin/cut
fi

# For -h, we query the usage statement
if [ $HFLAG -eq 1 ]
then
 
	echo -e $USAGE;
	exit 14;

fi


# For -q, we query whether or not IBNM software is enabled in /etc/inittab
if [ $QFLAG -eq 1 ]
then
	# Perform the query function
	grep_results=`/bin/grep startIBNM /etc/inittab`
	if [[ $grep_results == "" ]]
	then
		# No entry in /etc/inittab - should not happen
		echo 10;
		echo No entry in /etc/inittab for startIBNM, exiting ...;
		exit 10 
	fi

	first_char=`echo $grep_results | $CUT -c 1`	#grep first char when grepping for ibnmd 
	if [[ $first_char == "i" ]]			#if first char is an i then daemon activated
	then
		# IBNM software is activated
	        num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmd"`    #grep number of threads
        
                if [ $num_grep_lines -ge 1 ]			#if threads = 1 then we are good
                then
                       let up=$up+1
                else
			let up=$up-1
			echo "Not enough threads <ibnmd> Software not fully functional."; 
		fi

		# IBNM software is activated
                num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmsmd"`    #grep number of threads
        
                if [ $num_grep_lines -ge 7 ]                    #if threads = 3 then we are good
                then
                       let up=$up+1
                else
                        let up=$up-1
			echo "Not enough threads <ibnmsmd> Software not fully functional.";
                fi

		# IBNM software is activated
                num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmfspd"`    #grep number of threads
        
                if [ $num_grep_lines -ge 3 ]                    #if threads = 3 then we are good
                then
                       let up=$up+1
                else
                        let up=$up-1
			echo "Not enough threads <ibnmfspd> Software not fully functional"; 
                fi

		# IBNM software is activated
                num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmtopod"`    #grep number of threads
        
                if [ $num_grep_lines -ge 6 ]                    #if threads = 3 then we are good
                then
                       let up=$up+1
                else
                        let up=$up-1
			echo "Not enough threads <ibnmtopod> Software not fully functional."; 
                fi

		# IBNM software is activated
                num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmiod"`    #grep number of threads

                if [ $num_grep_lines -ge 4 ]                    #if threads = 3 then we are good
                then
                       let up=$up+1
                else
                	let up=$up-1 
		       echo "Not enough threads <ibnmiod> Software not fully functional."; 
                fi
	
		if [ $up == 5 ]
		then	
			echo 11;
			echo IBNMD software is activated; 
			exit 11
		else
			echo 13;
			echo IBMNM only partically active; 
			exit 13;
		fi
	else							#if daemon deactivated then exit
		# IBNM  software is de-activated
		echo "12"
		echo IBNMD software is de-activated;
		exit 12
	fi
fi

# For -a, perform the activate IBNMD software function
if [ $AFLAG -eq 1 ]
then
	#Perform the activate function - first see if it is already activated
	grep_results=`/bin/grep startIBNM /etc/inittab`
	if [[ $grep_results == "" ]]
	then
		# No entry in /etc/inittab - should not happen
		echo 4;
		echo No entry in /etc/inittab - should not happen;
		exit 4
	fi

	first_char=`echo $grep_results | $CUT -c 1`
	if [[ $first_char == "i" ]]
	then
		# IBNM software is activated already
		echo "1"
		echo IBNM software is activated already;
		exit 1
	else
		# Defect 128428 make sure isSP -> /opt/hsc/bin/isCecBpcIb
                # remove link
                /bin/rm /opt/hsc/bin/isSP

                # set link
                /bin/ln -s /opt/hsc/bin/isCecBpcIb /opt/hsc/bin/isSP

		#defect 131987 -- clean up TopoDB on each activate of ibnm
		/bin/rm -f /opt/hsc/data/ibnm/TopoDB

		# IBNM software is de-activated - need to activate it
		# First modify the entry from /etc/inittab to scratch file
		/bin/sed -e '/ibnm/s/^#ibnm:/ibnm:/g' /etc/inittab > /dump/hsc_dump_inittab
		if [[ $? -eq 0 ]]
		# Check for sed completion
		then
			# check space in root directory
			look_for_root1=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f19` 
			look_for_root2=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f20`
			look_for_root3=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f21`
			look_for_root4=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f22`
			look_for_root5=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f23`
			look_for_root6=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f24`

		  	if [[ $look_for_root1 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f18 | /usr/bin/cut -d"%" -f1`
			fi	
		  	
			if [[ $look_for_root2 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f19 | /usr/bin/cut -d"%" -f1`
			fi	
		  	
			if [[ $look_for_root3 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f20 | /usr/bin/cut -d"%" -f1`
			fi	
		  	
			if [[ $look_for_root4 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f21 | /usr/bin/cut -d"%" -f1`
			fi	
			
			if [[ $look_for_root5 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f22 | /usr/bin/cut -d"%" -f1`
			fi	
			if [[ $look_for_root6 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f23 | /usr/bin/cut -d"%" -f1`
			fi	
			
			if [[ $space_avail -ge 95 ]]
			then
				echo 3
				echo IBM NM did not activate successfully.
				echo Not enough space in /root device.
				exit 3
			else				
				# sed completed successfully - move the file back
				/bin/rm -f /etc/inittab
				/bin/mv /dump/hsc_dump_inittab /etc/inittab
			fi
		fi

		# Cause the file to be re-examined
		/sbin/telinit q
		
		# Open SNMP port if closed
                #/bin/sed 's/<net_app app_id="snmptrap.name" public_default="deny" private_default="deny">/<net_app app_id="snmptrap.name" public_default="allow" private_default="allow">/' /opt/ccfw/data/network/network_config.xml > /dump/snmp_162_tmp
                #/bin/cp -p /opt/ccfw/data/network/network_config.xml /opt/ccfw/data/network/network_config.xml.bak
                
		#/bin/mv /dump/snmp_162_tmp /opt/ccfw/data/network/network_config.xml
	
		table_results=`/usr/sbin/iptables -L eth0-NETAPP-INPUT | /bin/grep snmptrap`
	
		if [[ $table_results == "" ]]	
		then
			# add entry to iptables
                	/usr/sbin/iptables -A eth0-NETAPP-INPUT -p tcp --destination-port 162 -j ACCEPT > /dump/ibsnmp.out 2>&1
                	/usr/sbin/iptables -A eth0-NETAPP-INPUT -p udp --destination-port 162 -j ACCEPT >> /dump/ibsnmp.out 2>&1
		fi
	 	
			
		table_results=`/usr/sbin/iptables -L eth1-NETAPP-INPUT | /bin/grep snmptrap`
		if [[ $table_results == "" ]]	
		then
			/usr/sbin/iptables -A eth1-NETAPP-INPUT -p tcp --destination-port 162 -j ACCEPT > /dump/ibsnmp.out 2>&1
                	/usr/sbin/iptables -A eth1-NETAPP-INPUT -p udp --destination-port 162 -j ACCEPT >> /dump/ibsnmp.out 2>&1
		fi

		# check if eth2 interface exists. if so add iptable entry 
		table_results=`/usr/sbin/iptables -L | /bin/grep eth2`
        	
			if [[ $table_results != "" ]]
			then
				 		
				table_results=`/usr/sbin/iptables -L eth2-NETAPP-INPUT | /bin/grep snmptrap`
				if [[ $table_results == "" ]]	
				then
					/usr/sbin/iptables -A eth2-NETAPP-INPUT -p tcp --destination-port 162 -j ACCEPT > /dump/ibsnmp.out 2>&1
                			/usr/sbin/iptables -A eth2-NETAPP-INPUT -p udp --destination-port 162 -j ACCEPT >> /dump/ibsnmp.out 2>&1
				fi
			fi

		# Now we wait
		# Use end as the while loop ending indicator, up is the
		#      signal that the daemon is up, and count will track
		#      how many sleep 5's we do.  If we get to 60, that's
		#      five minutes, and that's too long.
		end=0
		up=0
		count=0
		ibnmd=0 
                ibnmsmd=0
                ibnmtopod=0 
                ibnmfspd=0      
                ibnmiod=0
		while test $end -eq 0
		do
			sleep 5
			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmd"`
			if [[ $num_grep_lines -ge 1 && $ibnmd -ne 1 ]]
			then
					let up=$up+1
					let ibnmd=1
			fi
			
			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmsmd"`
			if [[ $num_grep_lines -ge 7 && $ibnmsmd -ne 1 ]]
                        then
                                        let up=$up+1
					let ibnmsmd=1
                        fi

			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmfspd"`
                        if [[ $num_grep_lines -ge 3 && $ibnmfspd -ne 1 ]]
                        then
                                        let up=$up+1
					let ibnmfspd=1
                        fi

			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmtopod"`
                        if [[ $num_grep_lines -ge 6 && $ibnmtopod -ne 1 ]]
                        then
                                        let up=$up+1
					let ibnmtopod=1
                        fi

			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmiod"`
                        if [[ $num_grep_lines -ge 4 && $ibnmiod -ne 1 ]]
                        then
                                        let up=$up+1
					let ibnmiod=1
                        fi

                        let  count=$count+1
                        if (($count == 60 || $up == 5))
			then
				end=1
                        fi
		done	

                if (($count == 60))
		then
			# We exited because 5 minutes are up
			echo "2"
			echo We exited because 5 minutes are up and daemon has not started;
			exit 2
		else
			/bin/sleep 10
			echo "0"
			echo Threads came up within 5 minutes. Daemon is running OK.;
			exit 0
		fi
	fi
fi

# For -d, perform the de-activate IBNM software function
if [ $DFLAG -eq 1 ]
then
	#Perform the de-activate function - first see if it is already de-activated
	grep_results=`/bin/grep startIBNM /etc/inittab`
	if [[ $grep_results == "" ]]
	then
		# No entry in /etc/inittab - should not happen
		echo 5;
		echo No entry in /etc/inittab - should not happen;
		exit 5
	fi

	first_char=`echo $grep_results | $CUT -c 1`
	if [[ $first_char == "#" ]] 
	then
		# IBNM software is de-activated already
		echo "6"
		echo IBNM software is de-activated already;
		exit 6
	else
		# Defect 128428 make sure isSP -> /opt/hsc/bin/isCecBpc
                # remove link
                /bin/rm /opt/hsc/bin/isSP
        
                # set link
                /bin/ln -s /opt/hsc/bin/isCecBpc /opt/hsc/bin/isSP

		# IBNM software is activated - need to de-activate it
		# First modify the entry from /etc/inittab to scratch file
		/bin/sed -e '/ibnm/s/^ibnm:/#ibnm:/g' /etc/inittab > /dump/hsc_dump_inittab
		if [[ $? -eq 0 ]]
		# Check for sed completion
		then
			# check space in root directory
			look_for_root1=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f19` 
			look_for_root2=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f20`
			look_for_root3=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f21`
			look_for_root4=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f22`
			look_for_root5=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f23`
			look_for_root6=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f24`

		  	if [[ $look_for_root1 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f18 | /usr/bin/cut -d"%" -f1`
			fi	
		  	
			if [[ $look_for_root2 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f19 | /usr/bin/cut -d"%" -f1`
			fi	
		  	
			if [[ $look_for_root3 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f20 | /usr/bin/cut -d"%" -f1`
			fi	
		  	
			if [[ $look_for_root4 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f21 | /usr/bin/cut -d"%" -f1`
			fi	
			
			if [[ $look_for_root5 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f22 | /usr/bin/cut -d"%" -f1`
			fi	
			if [[ $look_for_root6 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f23 | /usr/bin/cut -d"%" -f1`
			fi	
			
			if [[ $space_avail -ge 95 ]]
			then
				echo 7
				echo IBM NM did not de-activate successfully.
				echo Not enough space in /root device.
				exit 7
			else				
				# sed completed successfully - move the file back
				/bin/rm -f /etc/inittab
				/bin/mv /dump/hsc_dump_inittab /etc/inittab
			fi
		else
			# sed did not complete - leave inittab alone - exi
			echo 8
			echo IBM NM did not de-activate successfully.
			echo Check for available space in /dump device.
			exit 8
		fi

		# Cause the file to be re-examined
		/sbin/telinit q
		
		# close the SNMP port if closed
                #/bin/sed 's/<net_app app_id="snmptrap.name" public_default="allow" private_default="allow">/<net_app app_id="snmptrap.name" public_default="allow" private_default="allow">/' /opt/ccfw/data/network/network_config.xml > /dump/snmp_162_tmp
                #/bin/cp -p /opt/ccfw/data/network/network_config.xml /opt/ccfw/data/network/network_config.xml.bak
                                                                                                                             
                table_results=`/usr/sbin/iptables -L eth0-NETAPP-INPUT | /bin/grep snmptrap`
                                                                                                                             
                if [[ $table_results != "" ]]
		then
                        # add entry to iptables
                        /usr/sbin/iptables -D eth0-NETAPP-INPUT -p tcp --destination-port 162 -j ACCEPT > /dump/ibsnmp.out 2>&1
                        /usr/sbin/iptables -D eth0-NETAPP-INPUT -p udp --destination-port 162 -j ACCEPT >> /dump/ibsnmp.out 2>&1
                fi
                                                                                                                             
                                                                                                                             
                table_results=`/usr/sbin/iptables -L eth1-NETAPP-INPUT | /bin/grep snmptrap`
                if [[ $table_results != "" ]]
		then
                        /usr/sbin/iptables -D eth1-NETAPP-INPUT -p tcp --destination-port 162 -j ACCEPT > /dump/ibsnmp.out 2>&1
                        /usr/sbin/iptables -D eth1-NETAPP-INPUT -p udp --destination-port 162 -j ACCEPT >> /dump/ibsnmp.out 2>&1
                fi
                                                                                                                             
                # check if eth2 interface exists. if so add iptable entry
                table_results=`/usr/sbin/iptables -L | /bin/grep eth2`
                                                                                                                             
                        if [[ $table_results != "" ]]
			then
                                                                                                                             
                                table_results=`/usr/sbin/iptables -L eth2-NETAPP-INPUT | /bin/grep snmptrap`
                                if [[ $table_results != "" ]]
				then
                                        /usr/sbin/iptables -D eth2-NETAPP-INPUT -p tcp --destination-port 162 -j ACCEPT > /dump/ibsnmp.out 2>&1
                                        /usr/sbin/iptables -D eth2-NETAPP-INPUT -p udp --destination-port 162 -j ACCEPT >> /dump/ibsnmp.out 2>&1
                                fi
			fi
		
		# Now we wait
		# Use end as the while loop ending indicator, down is the
		#      signal that the daemon is down (0 threads), and count
		#      wil track how many sleep 5's we do.  If we get to 6, 
		#      that's thirty seconds, and that's too long.
		end=0
		down=0
		count=0
		ibnmd=0
		ibnmsmd=0
		ibnmtopod=0
		ibnmfspd=0
		ibnmiod=0
		while test $end -eq 0
		do
			sleep 5
			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmd"`
			if [[ $num_grep_lines -eq 1 && $ibnmd -ne 1 ]]
			then
					let down=$down+1
					let ibnmd=1
		        else
			  if [[ $ibnmd -ne 1 ]]
			  then
		    	  	ibnmpid=`/bin/ps -C "ibnmd" | /usr/bin/cut -d" " -f1 | /bin/sed '1d'`
				
				if [[ $ibnmpid -gt 0 ]]
				then
			  		kill -9 $ibnmpid
					ibnmpid=0
				fi
			  fi
			fi

			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmsmd"`
                        if [[ $num_grep_lines -eq 1  && $ibnmsmd -ne 1 ]]
                        then
                                        let down=$down+1
					let ibnmsmd=1
                        else 
			  if [[ $ibnmsmd -ne 1 ]]
			  then
			  	ibnmpid=`/bin/ps -C "ibnmsmd" | /bin/sed '3,9d' | /usr/bin/cut -d" " -f1 | /bin/sed '1d'`
			  	
				if [[ $ibnmpid -gt 0 ]]
				then
					kill -9 $ibnmpid
					ibnmpid=0
				fi
			  fi
			fi
			

			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmfspd"`
                        if [[ $num_grep_lines -eq 1 && $ibnmfspd -ne 1 ]]
                        then
                                        let down=$down+1
					let ibnmfspd=1
               		else
			   if [[ $ibnmfspd -ne 1 ]]
			   then
				ibnmpid=`/bin/ps -C "ibnmfspd" | /bin/sed '3,8d' | /usr/bin/cut -d" " -f1 | /bin/sed '1d'` 
				
				if [[ $ibnmpid -gt 0 ]]
                                then
					kill -9 $ibnmpid
					ibnmpid=0
				fi
			   fi
			fi

			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmtopod"`
                        if [[ $num_grep_lines -eq 1 && $ibnmtopod -ne 1 ]]
                        then
                                        let down=$down+1
					let ibnmtopod=1
                        else
			    if [[ $ibnmtopod -ne 1 ]]
			    then
				ibnmpid=`/bin/ps -C "ibnmtopod" | /bin/sed '3,9d' | /usr/bin/cut -d" " -f1 | /bin/sed '1d'`
			
				if [[ $ibnmpid -gt 0 ]]
                                then	
					kill -9 $ibnmpid
					ibnmpid=0
				fi
			    fi
			fi

			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmiod"`
                        if [[ $num_grep_lines -eq 1 && $ibnmiod -ne 1 ]]
                        then
                                        let down=$down+1
					let ibnmiod=1
                        else
			    if [[ $ibnmiod -ne 1 ]]
			    then
				ibnmpid=`/bin/ps -C "ibnmiod" | /bin/sed '3,8d' | /usr/bin/cut -d" " -f1 | /bin/sed '1d'`
	
				if [[ $ibnmpid -gt 0 ]]
                                then
					kill -9 $ibnmpid
					ibnmpid=0
				fi
			    fi
			fi

                        let  count=$count+1
                        if (($count == 6 || $down == 5))
			then
				end=1
                        fi
		done	

                if (($count == 6))
		then
			# We exited because 30 seconds are up
			exit_ret=9
			echo "$exit_ret"
			echo Daemons could not be deactivated successfully;
			exit $exit_ret
		else
			exit_ret=0
		fi

		#/bin/sed -e '/^ibnm:/d' /etc/inittab 2>/dev/null > /dump/hsc_dump_inittab
		# Now add the commented entry and mv the file back
		#echo "#ibnm:2345:respawn:/opt/hsc/bin/startIBNM 1>/dev/null 2>&1" >> /dump/hsc_dump_inittab
		#/bin/mv /dump/hsc_dump_inittab /etc/inittab

		# Cause the file to be re-examined
		#/sbin/telinit q
		echo "$exit_ret"
		echo The ibnm daemons have been deactivated successfully;
		/opt/hsc/bin/SetIbnm -d > /dump/SetIbnm.dump
		/bin/rm /dump/SetIbnm.dump
		exit $exit_ret
	fi

fi
# For -c, perform the de-activate IBNM software function
if [ $CFLAG -eq 1 ]
then
	#Perform the de-activate function - first see if it is already de-activated
	grep_results=`/bin/grep startIBNM /etc/inittab`
	if [[ $grep_results == "" ]]
	then
		# No entry in /etc/inittab - should not happen
		echo 4;
		echo No entry in /etc/inittab - should not happen;
		exit 4
	fi

	first_char=`echo $grep_results | $CUT -c 1`
	if [[ $first_char == "#" ]] 
	then
		# IBNM software is de-activated already
		echo "1"
		echo IBNM software is de-activated already;
		exit 1
	else
		# IBNM software is activated - need to de-activate it
		# First modify the entry from /etc/inittab to scratch file
		/bin/sed -e '/ibnm/s/^ibnm:/#ibnm:/g' /etc/inittab > /dump/hsc_dump_inittab
		if [[ $? -eq 0 ]]
		# Check for sed completion
		then
			# check space in root directory
			look_for_root1=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f19` 
			look_for_root2=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f20`
			look_for_root3=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f21`
			look_for_root4=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f22`
			look_for_root5=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f23`
			look_for_root6=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f24`

		  	if [[ $look_for_root1 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f18 | /usr/bin/cut -d"%" -f1`
			fi	
		  	
			if [[ $look_for_root2 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f19 | /usr/bin/cut -d"%" -f1`
			fi	
		  	
			if [[ $look_for_root3 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f20 | /usr/bin/cut -d"%" -f1`
			fi	
		  	
			if [[ $look_for_root4 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f21 | /usr/bin/cut -d"%" -f1`
			fi	
			
			if [[ $look_for_root5 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f22 | /usr/bin/cut -d"%" -f1`
			fi	
			if [[ $look_for_root6 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f23 | /usr/bin/cut -d"%" -f1`
			fi	
			
			if [[ $space_avail -ge 95 ]]
			then
				echo 4
				echo IBM NM did not de-activate successfully.
				echo Not enough space in /root device.
				exit 4
			else				
				# sed completed successfully - move the file back
				/bin/rm -f /etc/inittab
				/bin/mv /dump/hsc_dump_inittab /etc/inittab
			fi
		else
			# sed did not complete - leave inittab alone - exi
			echo 4
			echo IBM NM did not de-activate successfully.
			echo Check for available space in /dump device.
			exit 4
		fi

		# Cause the file to be re-examined
		/sbin/telinit q
		
		# close the SNMP port if closed
                #/bin/sed 's/<net_app app_id="snmptrap.name" public_default="allow" private_default="allow">/<net_app app_id="snmptrap.name" public_default="allow" private_default="allow">/' /opt/ccfw/data/network/network_config.xml > /dump/snmp_162_tmp
                #/bin/cp -p /opt/ccfw/data/network/network_config.xml /opt/ccfw/data/network/network_config.xml.bak
                                                                                                                             
                #/bin/mv /dump/snmp_162_tmp /opt/ccfw/data/network/network_config.xml
                                                                                                                             
                table_results=`/bin/grep snmptrap /usr/sbin/iptables -L`
                                                                                                                             
                if [[ $table_results -ne "" ]]
                then
                        # add entry to iptables
                        /usr/sbin/iptables -D eth1-NETAPP-INPUT -p tcp --destination-port 162 -j ACCEPT
                        /usr/sbin/iptables -D eth0-NETAPP-INPUT -p tcp --destination-port 162 -j ACCEPT
                                                                                                                             
                        /usr/sbin/iptables -D eth1-NETAPP-INPUT -p udp --destination-port 162 -j ACCEPT
                        /usr/sbin/iptables -D eth0-NETAPP-INPUT -p udp --destination-port 162 -j ACCEPT
                                                                                                                             
                        # check if eth2 interface exists. if so add iptable entry
                        table_results=`/bin/grep eth2 /usr/sbin/iptables -L`
                                                                                                                             
                        if [[ $table_results -ne "" ]]
                        then
                                /usr/sbin/iptables -D eth2-NETAPP-INPUT -p udp --destination-port 162 -j ACCEPT
                                /usr/sbin/iptables -D eth2-NETAPP-INPUT -p udp --destination-port 162 -j ACCEPT
                        fi
                fi

		# Now we wait
		# Use end as the while loop ending indicator, down is the
		#      signal that the daemon is down (0 threads), and count
		#      wil track how many sleep 5's we do.  If we get to 6, 
		#      that's thirty seconds, and that's too long.
		end=0
		down=0
		count=0
		ibnmd=0
		ibnmsmd=0
		ibnmtopod=0
		ibnmfspd=0
		ibnmiod=0
		while test $end -eq 0
		do
			sleep 5
			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmd"`
			if [[ $num_grep_lines -eq 1 && $ibnmd -ne 1 ]]
			then
					let down=$down+1
					let ibnmd=1
		        else
			  if [[ $ibnmd -ne 1 ]]
			  then
		    	  	ibnmpid=`/bin/ps -C "ibnmd" | /usr/bin/cut -d" " -f1 | /bin/sed '1d'`
				
				if [[ $ibnmpid -gt 0 ]]
				then
			  		kill -9 $ibnmpid
					ibnmpid=0
				fi
			  fi
			fi

			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmsmd"`
                        if [[ $num_grep_lines -eq 1  && $ibnmsmd -ne 1 ]]
                        then
                                        let down=$down+1
					let ibnmsmd=1
                        else 
			  if [[ $ibnmsmd -ne 1 ]]
			  then
			  	ibnmpid=`/bin/ps -C "ibnmsmd" | /bin/sed '3,9d' | /usr/bin/cut -d" " -f1 | /bin/sed '1d'`
			  	
				if [[ $ibnmpid -gt 0 ]]
				then
					kill -9 $ibnmpid
					ibnmpid=0
				fi
			  fi
			fi
			

			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmfspd"`
                        if [[ $num_grep_lines -eq 1 && $ibnmfspd -ne 1 ]]
                        then
                                        let down=$down+1
					let ibnmfspd=1
               		else
			   if [[ $ibnmfspd -ne 1 ]]
			   then
				ibnmpid=`/bin/ps -C "ibnmfspd" | /bin/sed '3,8d' | /usr/bin/cut -d" " -f1 | /bin/sed '1d'` 
				
				if [[ $ibnmpid -gt 0 ]]
                                then
					kill -9 $ibnmpid
					ibnmpid=0
				fi
			   fi
			fi

			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmtopod"`
                        if [[ $num_grep_lines -eq 1 && $ibnmtopod -ne 1 ]]
                        then
                                        let down=$down+1
					let ibnmtopod=1
                        else
			    if [[ $ibnmtopod -ne 1 ]]
			    then
				ibnmpid=`/bin/ps -C "ibnmtopod" | /bin/sed '3,9d' | /usr/bin/cut -d" " -f1 | /bin/sed '1d'`
			
				if [[ $ibnmpid -gt 0 ]]
                                then	
					kill -9 $ibnmpid
					ibnmpid=0
				fi
			    fi
			fi

			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmiod"`
                        if [[ $num_grep_lines -eq 1 && $ibnmiod -ne 1 ]]
                        then
                                        let down=$down+1
					let ibnmiod=1
                        else
			    if [[ $ibnmiod -ne 1 ]]
			    then
				ibnmpid=`/bin/ps -C "ibnmiod" | /bin/sed '3,8d' | /usr/bin/cut -d" " -f1 | /bin/sed '1d'`
	
				if [[ $ibnmpid -gt 0 ]]
                                then
					kill -9 $ibnmpid
					ibnmpid=0
				fi
			    fi
			fi

                        let  count=$count+1
                        if (($count == 6 || $down == 5))
			then
				end=1
                        fi
		done	

                if (($count == 6))
		then
			# We exited because 30 seconds are up
			exit_ret=2
			echo "$exit_ret"
			echo Daemons could not be deactivated successfully;
			exit $exit_ret
		else
			exit_ret=0
		fi

		#/bin/sed -e '/^ibnm:/d' /etc/inittab 2>/dev/null > /dump/hsc_dump_inittab
		# Now add the commented entry and mv the file back
		#echo "#ibnm:2345:respawn:/opt/hsc/bin/startIBNM 1>/dev/null 2>&1" >> /dump/hsc_dump_inittab
		#/bin/mv /dump/hsc_dump_inittab /etc/inittab

		# Cause the file to be re-examined
		#/sbin/telinit q
		echo "$exit_ret"
		echo The ibnm daemons have been deactivated successfully;
		exit $exit_ret
	fi
	
fi
# For -o, perform the activate IBNMD software function
if [ $OFLAG -eq 1 ]
then
	#Perform the activate function - first see if it is already activated
	grep_results=`/bin/grep startIBNM /etc/inittab`
	if [[ $grep_results == "" ]]
	then
		# No entry in /etc/inittab - should not happen
		echo 4;
		echo No entry in /etc/inittab - should not happen;
		exit 4
	fi

	first_char=`echo $grep_results | $CUT -c 1`
	if [[ $first_char == "i" ]]
	then
		# IBNM software is activated already
		echo "1"
		echo IBNM software is activated already;
		exit 1
	else
		#defect 131987 -- clean up TopoDB on each activate of ibnm
		/bin/rm -f /opt/hsc/data/ibnm/TopoDB
		
		# IBNM software is de-activated - need to activate it
		# First modify the entry from /etc/inittab to scratch file
		/bin/sed -e '/ibnm/s/^#ibnm:/ibnm:/g' /etc/inittab > /dump/hsc_dump_inittab
		
		if [[ $? -eq 0 ]]
		# Check for sed completion
		then
			# check space in root directory
			look_for_root1=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f19` 
			look_for_root2=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f20`
			look_for_root3=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f21`
			look_for_root4=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f22`
			look_for_root5=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f23`
			look_for_root6=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f24`

		  	if [[ $look_for_root1 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f18 | /usr/bin/cut -d"%" -f1`
			fi	
		  	
			if [[ $look_for_root2 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f19 | /usr/bin/cut -d"%" -f1`
			fi	
		  	
			if [[ $look_for_root3 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f20 | /usr/bin/cut -d"%" -f1`
			fi	
		  	
			if [[ $look_for_root4 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f21 | /usr/bin/cut -d"%" -f1`
			fi	
			
			if [[ $look_for_root5 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f22 | /usr/bin/cut -d"%" -f1`
			fi	
			if [[ $look_for_root6 == "/" ]]
			then
				space_avail=`/bin/df -k | /bin/grep hda2 | /usr/bin/cut -d" " -f23 | /usr/bin/cut -d"%" -f1`
			fi	
			
			if [[ $space_avail -ge 95 ]]
			then
				echo 4
				echo IBM NM did not activate successfully.
				echo Not enough space in /root device.
				exit 4
			else				
				# sed completed successfully - move the file back
				/bin/rm -f /etc/inittab
				/bin/mv /dump/hsc_dump_inittab /etc/inittab
			fi
		else
			# sed did not complete - leave inittab alone - exi
			echo 4
			echo IBM NM did not de-activate successfully.
			echo Check for available space in /dump device.
			exit 4
		fi

		# Cause the file to be re-examined
		/sbin/telinit q
		
		# Open SNMP port if closed
                #/bin/sed 's/<net_app app_id="snmptrap.name" public_default="deny" private_default="deny">/<net_app app_id="snmptrap.name" public_default="allow" private_default="allow">/' /opt/ccfw/data/network/network_config.xml > /dump/snmp_162_tmp
                #/bin/cp -p /opt/ccfw/data/network/network_config.xml /opt/ccfw/data/network/network_config.xml.bak
                                                                                                                             
                #/bin/mv /dump/snmp_162_tmp /opt/ccfw/data/network/network_config.xml
                                                                                                                             
                table_results=`/bin/grep snmptrap /usr/sbin/iptables -L`
                                                                                                                             
                if [[ $table_results == "" ]]
                then
                        # add entry to iptables
                        /usr/sbin/iptables -A eth1-NETAPP-INPUT -p tcp --destination-port 162 -j ACCEPT
                        /usr/sbin/iptables -A eth0-NETAPP-INPUT -p tcp --destination-port 162 -j ACCEPT
                                                                                                                             
                        /usr/sbin/iptables -A eth1-NETAPP-INPUT -p udp --destination-port 162 -j ACCEPT
                        /usr/sbin/iptables -A eth0-NETAPP-INPUT -p udp --destination-port 162 -j ACCEPT
                                                                                                                             
                        # check if eth2 interface exists. if so add iptable entry
                        table_results=`/bin/grep eth2 /usr/sbin/iptables -L`
                                                                                                                             
                        if [[ $table_results != "" ]]
                        then
                                /usr/sbin/iptables -A eth2-NETAPP-INPUT -p udp --destination-port 162 -j ACCEPT
                                /usr/sbin/iptables -A eth2-NETAPP-INPUT -p udp --destination-port 162 -j ACCEPT
                        fi
                fi
	
		# Now we wait
		# Use end as the while loop ending indicator, up is the
		#      signal that the daemon is up, and count will track
		#      how many sleep 5's we do.  If we get to 60, that's
		#      five minutes, and that's too long.
		end=0
		up=0
		count=0
		ibnmd=0 
                ibnmsmd=0
                ibnmtopod=0 
                ibnmfspd=0      
                ibnmiod=0
		while test $end -eq 0
		do
			sleep 5
			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmd"`
			if [[ $num_grep_lines -ge 1 && $ibnmd -ne 1 ]]
			then
					let up=$up+1
					let ibnmd=1
			fi
			
			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmsmd"`
			if [[ $num_grep_lines -ge 7 && $ibnmsmd -ne 1 ]]
                        then
                                        let up=$up+1
					let ibnmsmd=1
                        fi

			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmfspd"`
                        if [[ $num_grep_lines -ge 3 && $ibnmfspd -ne 1 ]]
                        then
                                        let up=$up+1
					let ibnmfspd=1
                        fi

			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmtopod"`
                        if [[ $num_grep_lines -ge 6 && $ibnmtopod -ne 1 ]]
                        then
                                        let up=$up+1
					let ibnmtopod=1
                        fi

			num_grep_lines=`/bin/ps -efL | /bin/grep -c "/opt/hsc/bin/ibnmiod"`
                        if [[ $num_grep_lines -ge 4 && $ibnmiod -ne 1 ]]
                        then
                                        let up=$up+1
					let ibnmiod=1
                        fi

                        let  count=$count+1
                        if (($count == 60 || $up == 5))
			then
				end=1
                        fi
		done	

                if (($count == 60))
		then
			# We exited because 5 minutes are up
			echo "2"
			echo We exited because 5 minutes are up and daemon has not started;
			exit 2
		else
			/bin/sleep 10
			echo "0"
			echo Threads came up within 5 minutes. Daemon is running OK.;
			exit 0
		fi
	fi
fi

exit 0
